# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.feature_store.serving import management_pb2 as qwak_dot_feature__store_dot_serving_dot_management__pb2


class FeaturesetManagementServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetFeaturesetMemoryUsageById = channel.unary_unary(
                '/com.qwak.ai.feature.store.serving.api.FeaturesetManagementService/GetFeaturesetMemoryUsageById',
                request_serializer=qwak_dot_feature__store_dot_serving_dot_management__pb2.GetFeaturesetMemoryUsageByIdRequest.SerializeToString,
                response_deserializer=qwak_dot_feature__store_dot_serving_dot_management__pb2.GetFeaturesetMemoryUsageByIdResponse.FromString,
                )
        self.GetFeaturesetMemoryUsageByEnvironment = channel.unary_unary(
                '/com.qwak.ai.feature.store.serving.api.FeaturesetManagementService/GetFeaturesetMemoryUsageByEnvironment',
                request_serializer=qwak_dot_feature__store_dot_serving_dot_management__pb2.GetFeaturesetMemoryUsageByEnvironmentRequest.SerializeToString,
                response_deserializer=qwak_dot_feature__store_dot_serving_dot_management__pb2.GetFeaturesetMemoryUsageByEnvironmentResponse.FromString,
                )


class FeaturesetManagementServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetFeaturesetMemoryUsageById(self, request, context):
        """get memory usage for a single Featureset
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFeaturesetMemoryUsageByEnvironment(self, request, context):
        """get memory usage stats for an entire env
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_FeaturesetManagementServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetFeaturesetMemoryUsageById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFeaturesetMemoryUsageById,
                    request_deserializer=qwak_dot_feature__store_dot_serving_dot_management__pb2.GetFeaturesetMemoryUsageByIdRequest.FromString,
                    response_serializer=qwak_dot_feature__store_dot_serving_dot_management__pb2.GetFeaturesetMemoryUsageByIdResponse.SerializeToString,
            ),
            'GetFeaturesetMemoryUsageByEnvironment': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFeaturesetMemoryUsageByEnvironment,
                    request_deserializer=qwak_dot_feature__store_dot_serving_dot_management__pb2.GetFeaturesetMemoryUsageByEnvironmentRequest.FromString,
                    response_serializer=qwak_dot_feature__store_dot_serving_dot_management__pb2.GetFeaturesetMemoryUsageByEnvironmentResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'com.qwak.ai.feature.store.serving.api.FeaturesetManagementService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class FeaturesetManagementService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetFeaturesetMemoryUsageById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.qwak.ai.feature.store.serving.api.FeaturesetManagementService/GetFeaturesetMemoryUsageById',
            qwak_dot_feature__store_dot_serving_dot_management__pb2.GetFeaturesetMemoryUsageByIdRequest.SerializeToString,
            qwak_dot_feature__store_dot_serving_dot_management__pb2.GetFeaturesetMemoryUsageByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFeaturesetMemoryUsageByEnvironment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.qwak.ai.feature.store.serving.api.FeaturesetManagementService/GetFeaturesetMemoryUsageByEnvironment',
            qwak_dot_feature__store_dot_serving_dot_management__pb2.GetFeaturesetMemoryUsageByEnvironmentRequest.SerializeToString,
            qwak_dot_feature__store_dot_serving_dot_management__pb2.GetFeaturesetMemoryUsageByEnvironmentResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/features_operator/v3/features_operator.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1qwak/features_operator/v3/features_operator.proto\x12\x19qwak.features_operator.v3\x1a\x1fgoogle/protobuf/timestamp.proto\"\x8c\x02\n\x19ValidationSuccessResponse\x12\x0e\n\x06sample\x18\x01 \x01(\t\x12U\n\x19pandas_column_description\x18\x02 \x03(\x0b\x32\x32.qwak.features_operator.v3.PandasColumnDescription\x12S\n\x18spark_column_description\x18\x03 \x03(\x0b\x32\x31.qwak.features_operator.v3.SparkColumnDescription\x12\x33\n\x07outputs\x18\x04 \x01(\x0b\x32\".qwak.features_operator.v3.Outputs\"C\n\x17PandasColumnDescription\x12\x13\n\x0b\x63olumn_name\x18\x01 \x01(\t\x12\x13\n\x0bpandas_type\x18\x02 \x01(\t\"A\n\x16SparkColumnDescription\x12\x13\n\x0b\x63olumn_name\x18\x01 \x01(\t\x12\x12\n\nspark_type\x18\x02 \x01(\t\"\x8b\x01\n\x19ValidationFailureResponse\x12\r\n\x05phase\x18\x01 \x01(\t\x12\x15\n\rerror_message\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x33\n\x07outputs\x18\x04 \x01(\x0b\x32\".qwak.features_operator.v3.Outputs\")\n\x07Outputs\x12\x0e\n\x06stdout\x18\x01 \x01(\t\x12\x0e\n\x06stderr\x18\x02 \x01(\t\"\x1c\n\x1aValidationNotReadyResponseB(\n$com.qwak.ai.features.operator.api.v3P\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.features_operator.v3.features_operator_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$com.qwak.ai.features.operator.api.v3P\001'
  _globals['_VALIDATIONSUCCESSRESPONSE']._serialized_start=114
  _globals['_VALIDATIONSUCCESSRESPONSE']._serialized_end=382
  _globals['_PANDASCOLUMNDESCRIPTION']._serialized_start=384
  _globals['_PANDASCOLUMNDESCRIPTION']._serialized_end=451
  _globals['_SPARKCOLUMNDESCRIPTION']._serialized_start=453
  _globals['_SPARKCOLUMNDESCRIPTION']._serialized_end=518
  _globals['_VALIDATIONFAILURERESPONSE']._serialized_start=521
  _globals['_VALIDATIONFAILURERESPONSE']._serialized_end=660
  _globals['_OUTPUTS']._serialized_start=662
  _globals['_OUTPUTS']._serialized_end=703
  _globals['_VALIDATIONNOTREADYRESPONSE']._serialized_start=705
  _globals['_VALIDATIONNOTREADYRESPONSE']._serialized_end=733
# @@protoc_insertion_point(module_scope)
